https://bugs.kde.org/show_bug.cgi?id=524780
--- Comment #9 from Ralf Habacker <[email protected]> --- (In reply to michael.spahr from comment #8) ... > Isolated reproduction (same nested QMap/QList types, 31 x 871 cells): > > as in renderHTML with the patch > Qt 5.15 3 ms 0 ms > Qt 6.4 1486 ms 0 ms > > This would also explain why you don't see it, if you build against Qt5. > Is that the case on your openSUSE Leap system? I remember creating the results using a Qt5-based kmymoney build, but I also ran the standalone tests on Qt6 for comparison; with the latter, there were no major differences, except that the QTextBrowser was slightly slower on Qt6. > 4) The patch Thank you very much for taking the time to provide this patch. You can find the result for Qt5 below. > 5) Result in the real application > nightly (no patch) with > patch > time to open the report ~60 s ~16 s By way of comparison: In a Qt5 version of KMyMoney, opening report R000183 on the computer mentioned earlier takes about 10 seconds—both with and without the patch. > So the remaining ~16 s are now almost entirely QTextBrowser, mostly > QTextDocumentLayout with QTextTableCell::firstCursorPosition() on top. That > is the problem you found, and it is independent of this patch. It also > explains why it is still slower than 5.1.3, which used WebEngine. With the next version of Alkimia, it would be possible to reintroduce QWebEngine via the Alkimia library to display reports if this performance issue persists. -- You are receiving this mail because: You are watching all bug changes.
